*********************
Community Information
*********************

Ansible Community Guide
=======================

Welcome to the Ansible Community Guide!

The purpose of this guide is to teach you everything you need to know about being a contributing member of the Ansible community.

To get started, select one of the following topics.


.. toctree::
   :maxdepth: 1

   development_process
   reporting_bugs_and_features
   how_can_I_help
   maintainers
   communication
   other_tools_and_programs



